==> currents-api-types-0.0.53.tgz: package/payin/route/parsers.ts <==
import { z } from 'zod';
import { MAX_HISTORICAL_DATE_MS } from '../../constants';
import { currencyAmountParser, currencyParser } from '../../currencies/parsers';
import { channelIdParser } from '../../channel/parsers';
import { userIdParser } from '../../user/parsers';
import type { PayinRouteResult } from './types';
import { makePositiveIntegerQueryParser } from '../../common/parsers/queryParams';
import { routingStrategyQueryParser } from '../../graph/strategy/parsers';
import { CHARGE_ROUTING_CONTEXT_ID_ROUTE_PARAM_NAME } from './constants';
import { timestampQueryParser } from '../../parsers';
import { FBIDHarderRegex } from '../../firebase/id/parsers';
import { ChargeRoutingContextContentId, ChargeRoutingContextId } from '../../audience/activation/context/types';
import { stripePaymentIntentIdParser } from '../../stripe/parsers';

export const routePacketQueryParser = z
  .object({
    userId: userIdParser,
    payeeId: channelIdParser,
    amt: currencyAmountParser,
    unit: currencyParser,
    when: makePositiveIntegerQueryParser('When')
      .refine((n) => n <= MAX_HISTORICAL_DATE_MS, {
        message: `"When" must be less than ${MAX_HISTORICAL_DATE_MS}`,
      })
      .optional(),
  })
  .merge(routingStrategyQueryParser);

export const routePacketResultParser = z.any(/* stub */).transform((v) => v as PayinRouteResult);

export const chargeRoutingContextIdParser = z
  .string()
  .regex(FBIDHarderRegex)
  .transform((s) => s as ChargeRoutingContextId);

export const chargeRoutingContextContentIdParser = channelIdParser.transform((s) => s as ChargeRoutingContextContentId); // TODO more

export const routeContextParamsParser = z.object({
  [CHARGE_ROUTING_CONTEXT_ID_ROUTE_PARAM_NAME]: chargeRoutingContextIdParser,
});

export const routeContextQueryParser = z.object({
  from: timestampQueryParser.optional(),
});

export const routeContextDetailsResultParser = routePacketResultParser;

export const routeContextBodyParser = z.object({
  contentId: chargeRoutingContextContentIdParser,
  to: timestampQueryParser.optional(),
});

export const routeContextInitResultParser = z.object({
  id: chargeRoutingContextIdParser,
});

export const chargeRoutingResultIdParser = stripePaymentIntentIdParser; // TODO more

export const routeContextBindBodyParser = z.object({
  graphId: chargeRoutingResultIdParser,
});

==> currents-api-types-0.0.58.tgz: package/payin/route/parsers.ts <==
import { z } from 'zod';
import { MAX_HISTORICAL_DATE_MS } from '../../constants';
import { currencyAmountParser, currencyParser } from '../../currencies/parsers';
import { channelIdParser } from '../../channel/parsers';
import { userIdParser } from '../../user/parsers';
import type { PayinRouteResult } from './types';
import { makePositiveIntegerQueryParser } from '../../common/parsers/queryParams';
import { routingStrategyQueryParser } from '../../graph/strategy/parsers';
import { CHARGE_ROUTING_CONTEXT_ID_ROUTE_PARAM_NAME } from './constants';
import { timestampQueryParser } from '../../parsers';
import { FBIDHarderRegex } from '../../firebase/id/parsers';
import { ChargeRoutingContextContentId, ChargeRoutingContextId } from '../../audience/activation/context/types';
import { stripePaymentIntentIdParser } from '../../stripe/parsers';

export const routePacketQueryParser = z
  .object({
    userId: userIdParser,
    payeeId: channelIdParser,
    amt: currencyAmountParser,
    unit: currencyParser,
    when: makePositiveIntegerQueryParser('When')
      .refine((n) => n <= MAX_HISTORICAL_DATE_MS, {
        message: `"When" must be less than ${MAX_HISTORICAL_DATE_MS}`,
      })
      .optional(),
  })
  .merge(routingStrategyQueryParser);

export const routePacketResultParser = z.any(/* stub */).transform((v) => v as PayinRouteResult);

export const chargeRoutingContextIdParser = z
  .string()
  .regex(FBIDHarderRegex)
  .transform((s) => s as ChargeRoutingContextId);

export const chargeRoutingContextContentIdParser = channelIdParser.transform((s) => s as ChargeRoutingContextContentId); // TODO more

export const routeContextParamsParser = z.object({
  [CHARGE_ROUTING_CONTEXT_ID_ROUTE_PARAM_NAME]: chargeRoutingContextIdParser,
});

export const routeContextQueryParser = z.object({
  from: timestampQueryParser.optional(),
});

export const routeContextDetailsResultParser = routePacketResultParser.and(
  z.object({
    contentId: chargeRoutingContextContentIdParser.nullable(),
  })
);

export const routeContextBodyParser = z.object({
  contentId: chargeRoutingContextContentIdParser,
  to: timestampQueryParser.optional(),
});

export const routeContextInitResultParser = z.object({
  id: chargeRoutingContextIdParser,
});

export const chargeRoutingResultIdParser = stripePaymentIntentIdParser; // TODO more

export const routeContextBindBodyParser = z.object({
  graphId: chargeRoutingResultIdParser,
});
